==> haskell-stmonadtrans-0.4.3-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: STMonadTrans
version: 0.4.3
id: STMonadTrans-0.4.3-6srbikYUYyU9WPN8LqzokE
key: STMonadTrans-0.4.3-6srbikYUYyU9WPN8LqzokE
license: BSD3
maintainer: josef.svenningsson@gmail.com
synopsis: A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.
category: Monads
author: Josef Svenningsson
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal
abi: a1c3324376e524ccd3e873ad6db19ee0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/STMonadTrans-0.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/STMonadTrans-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/STMonadTrans-0.4.3
hs-libraries: HSSTMonadTrans-0.4.3-6srbikYUYyU9WPN8LqzokE
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH array-0.5.2.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
haddock-interfaces: /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock
haddock-html: /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stmonadtrans-0.4.3-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: STMonadTrans
version: 0.4.3
id: STMonadTrans-0.4.3-7lSg3y2p8nw2EDstzyreuM
key: STMonadTrans-0.4.3-7lSg3y2p8nw2EDstzyreuM
license: BSD3
maintainer: josef.svenningsson@gmail.com
synopsis: A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.
category: Monads
author: Josef Svenningsson
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal
abi: 2564759b2ec7d1d4bc145d6890e641f5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/STMonadTrans-0.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/STMonadTrans-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/STMonadTrans-0.4.3
hs-libraries: HSSTMonadTrans-0.4.3-7lSg3y2p8nw2EDstzyreuM
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc array-0.5.2.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
haddock-interfaces: /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock
haddock-html: /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
